import { NearbyConfig, ErrorType } from 'index';
/**
 * The current status of the Google Nearby API (used in hooks)
 */
export declare type NearbyStatus = 'disconnected' | 'connecting' | 'published' | 'subscribed' | 'error' | 'denied' | 'unavailable';
/**
 * The state of a current Subscription. (used in hooks)
 */
export interface SubscriptionState {
    nearbyMessages: string[];
    nearbyStatus: NearbyStatus;
}
/**
 * The state of a current Subscription-Search. (used in hooks)
 */
export interface SearchState {
    isNearby: boolean;
    nearbyStatus: NearbyStatus;
}
/**
 * Publish a simple message and return the current status of the nearby API.
 *
 * Also calls `checkBluetoothAvailability()` and `checkBluetoothPermission()`.
 * @param config The Nearby API configuration object to use.
 * @param message The message to publish
 * @returns The current status of the Nearby API
 */
export declare function useNearbyPublication(config: NearbyConfig, message: string): NearbyStatus;
/**
 * Subscribe to nearby messages and return an instance of the `SubscriptionState` object.
 *
 * Also calls `checkBluetoothAvailability()` and `checkBluetoothPermission()`.
 * @param config The Nearby API configuration object to use.
 * @returns A state of all nearby messages
 */
export declare function useNearbySubscription(config: NearbyConfig): SubscriptionState;
/**
 * Search for a specific message using the nearby messages API. Returns an instance of the `SearchState` interface.
 *
 * Also calls `checkBluetoothAvailability()` and `checkBluetoothPermission()`.
 * @param config The Nearby API configuration object to use.
 * @param searchFor The string to perform the nearby search for
 * @returns A state whether the message has been found or not.
 */
export declare function useNearbySearch(config: NearbyConfig, searchFor: string): SearchState;
/**
 * Add an error listener which automatically disposes when the component unmounts.
 * @param callback The function to call when an error occurs.
 */
export declare function useNearbyErrorCallback(callback: (kind: ErrorType, message?: string) => void): void;
